@@ -337,13 +337,13 @@ class Connection(pymysql.Connection):
 
     # 一组更新语句,如果是需要一起提交,则可使用此语句, 或者批量更新都可用此语句
     def update_many(self,
-                    sqls: list[str],
+                    sqls: list,
                     args: list,
                     autocommit=True,
                     assert_for_exception: bool = False,
                     rollback_for_exception: bool = False):
         c = super().cursor()
-        results = list[int]()
+        results = list()
         try:
             _index = -1
             for sql in sqls:
@@ -387,7 +387,7 @@ class ConnectionPool:
         # 属性参数
         self.properties = properties
         # 可用连接队列
-        self.__conns__ = LifoQueue[Connection](properties.pool_maxsize)
+        self.__conns__ = LifoQueue(properties.pool_maxsize)
         # thread local
         self.__thread_local__ = threading.local()
         # 当前连接
@@ -609,7 +609,7 @@ class SqlParser:
     # 解析sql, 返回 [虚拟库名,真实sql,虚拟表名,真实表名]
     @staticmethod
     def parse(sql: str) -> tuple:
-        _sql = sql.lower().strip()
+        _sql = sql.strip()
         table_name = None
         _sql = _sql.replace('\n', " ")
         _sql = _sql.replace('\t', " ")
@@ -617,7 +617,7 @@ class SqlParser:
         _len = len(_splits)
         if SqlParser.is_select(sql) or SqlParser.is_delete(sql):
             for i in range(_len):
-                if _splits[i] == 'from':
+                if _splits[i].lower() == 'from':
                     if i < (_len - 1):
                         table_name = _splits[i + 1]
                         break
@@ -627,7 +627,7 @@ class SqlParser:
             pass
         elif SqlParser.is_insert(sql):
             for i in range(_len):
-                if _splits[i] == 'into':
+                if _splits[i].lower() == 'into':
                     if i < (_len - 1):
                         table_name = re.split(r'\(', _splits[i + 1])[0]
                         break
@@ -636,7 +636,7 @@ class SqlParser:
             pass
         elif SqlParser.is_update(sql):
             for i in range(_len):
-                if _splits[i] == 'update':
+                if _splits[i].lower() == 'update':
                     if i < (_len - 1):
                         table_name = _splits[i + 1]
                         break
